#
# spec file for package python-bitstring
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-bitstring
Version:        3.1.6
Release:        lp152.1.1
Summary:        Python module for the construction, analysis and modification of binary data
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/scott-griffiths/bitstring
Source:         https://github.com/scott-griffiths/bitstring/archive/bitstring-%{version}.tar.gz
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Bitstring is a pure Python module to aid
the creation and analysis of binary data.

Bitstrings can be constructed from integers (big and little endian), hex,
octal, binary, strings or files. They can be sliced, joined, reversed,
inserted into, overwritten, etc. with functions or slice notation.
They can also be read from, searched and replaced, and navigated in,
similar to a file or stream.

%prep
%setup -q -n bitstring-bitstring-%{version}
dos2unix README.rst
sed -i '1{\@^#!%{_bindir}/env python@d}' bitstring.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
cd test
%pytest

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/*

%changelog
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.1.6:
  * Fixed immutability bug. Bug 176.
  * Fixed failure of `__contains__` in some circumstances. Bug 180.
  * Better handling of open files. Bug 186.
  * Better Python 2/3 check.
  * Making unit tests easier to run.
  * Allowing length of 1 to be specified for bools. (Thanks to LemonPi)
* Wed Dec  5 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Dec 27 2017 jengelh@inai.de
- Trim filler words from description.
* Wed Oct 18 2017 toddrme2178@gmail.com
- Implement single-spec version
* Sun Jul 31 2016 mardnh@gmx.de
- Update to version 3.1.5
  * Support initialisation from an array.
  * Added a separate LICENSE file.
- Update to version 3.1.4
  * Fix for bitstring types when created directly from other bitstring types.
  * Updating contact, website details.
- Update to version 3.1.3
  * Fix for problem with prepend for bitstrings with byte offsets in their data store.
* Sat Apr 20 2013 p.drouand@gmail.com
- Update to version 3.1.2
  + this release has a fix for a problem where unpacked bytes could be
    eight times too long.
* Tue Feb 26 2013 p.drouand@gmail.com
- Update to version 3.1.0:
  * New 'pad' token
    This token can be used in reads and when packing/unpacking to indicate that
    you don't care about the contents of these bits. Any padding bits will just
    be skipped over when reading/unpacking or zero-filled when packing.
    >>> a, b = s.readlist('pad:5, uint:3, pad:1, uint:3')
    Here only two items are returned in the list - the padding bits are ignored.
  * New clear and copy convenience methods
    These methods have been introduced in Python 3.3 for lists and bytearrays,
    as more obvious ways of clearing and copying, and we mirror that change here.
    t = s.copy() is equivalent to t = s[:], and s.clear() is equivalent to del s[:].
  * Some bug fixes.
* Fri Jan 11 2013 p.drouand@gmail.com
- Initial python3 support
* Fri Jan 11 2013 p.drouand@gmail.com
- Fix wronf EOF and remove shebang on bitstring.py
* Fri Jan 11 2013 p.drouand@gmail.com
- Update to 3.0.2 version:
  * Fix for subclasses of bitstring classes behaving strangely ( Issue 121 ).
  * Fix for excessive memory usage in rare cases ( Issue 120 ).
  * Fixes for slicing edge cases.
* Fri Sep 23 2011 saschpe@suse.de
- Update to version 2.2.0:
  * Fix for Python 3.2, correcting for a change to the binascii module.
  * Fix for bool initialisation from 0 or 1.
  * Efficiency improvements, including interning strategy.
- Changes from version 2.1.1:
  * Bug fix: Reading using the 'bytes' token had been broken (Issue 102).
  * Fixed problem using some methods on ConstBitArrays.
  * Better exception handling for tokens missing values.
  * Some performance improvements.
- See release_notes.txt for further changes...
* Fri Mar 19 2010 toms@suse.de
- First initial version 1.3.0
